@@ -1064,7 +1064,22 @@ void removeHs(RWMol &mol, const RemoveHsParameters &ps, bool sanitize) {
   if (!atomsToRemove.empty() && ps.removeNonimplicit && sanitize) {
     sanitizeMol(mol);
   }
-};
+
+  // if we removed Hs and any chiral atoms now have more than 1 explict H,
+  // remove those
+  if (!atomsToRemove.empty()) {
+    for (auto atom : mol.atoms()) {
+      if (!atom->getNoImplicit() &&
+          atom->getChiralTag() != Atom::CHI_UNSPECIFIED) {
+        unsigned int numExplicitHs = atom->getNumExplicitHs();
+        if (numExplicitHs > 1) {
+          atom->setNumExplicitHs(0);
+          atom->updatePropertyCache(false);
+        }
+      }
+    }
+  }
+}
 ROMol *removeHs(const ROMol &mol, const RemoveHsParameters &ps, bool sanitize) {
   auto *res = new RWMol(mol);
   try {
